@@ -14,7 +14,7 @@
 #define LIBXMLXX_MINOR_VERSION 0
 
 /* Micro version number of libxml++. */
-#define LIBXMLXX_MICRO_VERSION 2
+#define LIBXMLXX_MICRO_VERSION 3
 
 #undef LIBXMLXX_STATIC
 
@@ -26,6 +26,10 @@
 #ifdef LIBXMLPP_DLL
   #ifdef LIBXMLPP_BUILD
     #define LIBXMLPP_API __declspec(dllexport)
+    #ifdef __GNUC__
+      #define LIBXMLPP_VISIBILITY_DEFAULT LIBXMLPP_API __attribute__((visibility("default")))
+      #define LIBXMLPP_MEMBER_METHOD
+    #endif
   #elif !defined (__GNUC__)
     #define LIBXMLPP_API __declspec(dllimport)
   #else /* don't dllimport classes/methods on GCC/MinGW */
@@ -36,5 +40,12 @@
   #define LIBXMLPP_API
 #endif /* GLIBMM_DLL */
 
+#ifndef LIBXMLPP_VISIBILITY_DEFAULT
+  #define LIBXMLPP_VISIBILITY_DEFAULT
+#endif
+#ifndef LIBXMLPP_MEMBER_METHOD
+  #define LIBXMLPP_MEMBER_METHOD LIBXMLPP_API
+#endif
+
 #endif /* _LIBXMLPP_CONFIG_H */
 
